==> eiffelstudio-16.05.tar: F_code/C47/sd2331.c <==
/*
 * Code for class SD_DOCKING_MANAGER_PROPERTY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "sd2331.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SD_DOCKING_MANAGER_PROPERTY}.make */
void F3291_39799 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 3290, Current, 0, 0, 41013);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {2540,3709,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F2521_28185(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.last_focus_content */
EIF_REFERENCE F3291_39800 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {SD_DOCKING_MANAGER_PROPERTY}.set_last_focus_content */
void F3291_39801 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("set_last_focus_content", 3290, Current, 0, 1, 41015);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	if ((EIF_BOOLEAN)(arg1 != NULL)) {
		RTHOOK(3);
		F3291_39811(Current, arg1);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.contents_by_click_order */
EIF_REFERENCE F3291_39802 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLR(4,loc3);
	RTLR(5,Result);
	RTLIU(6);
	
	RTEAA("contents_by_click_order", 3290, Current, 3, 0, 41016);
	RTGC;
	RTHOOK(1);
	loc2 = *(EIF_REFERENCE *)(RTCV(F2715_30004(Current)) + _REFACS_1_);
	RTHOOK(2);
	F2640_29151(RTCW(loc2));
	RTHOOK(3);
	{
		static EIF_TYPE_INDEX typarr0[] = {2639,3709,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNS(typres0.id, 2639, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	ti4_1 = F2640_29141(RTCW(loc2));
	F2640_29121(RTCW(tr1), ti4_1);
	loc1 = (EIF_REFERENCE) tr1;
	for (;;) {
		RTHOOK(4);
		tb1 = F2486_28004(RTCW(loc2));
		if (tb1) break;
		RTHOOK(5);
		tr1 = F2640_29125(RTCW(loc2));
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R17660[Dtype(loc1)-1604])(RTCW(loc1), tr1);
		RTHOOK(6);
		F2640_29153(RTCW(loc2));
	}
	RTHOOK(7);
	loc3 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	RTHOOK(8);
	{
		static EIF_TYPE_INDEX typarr0[] = {2639,3709,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNS(typres0.id, 2639, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F2640_29121(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(9);
	F2521_28203(RTCW(loc3));
	for (;;) {
		RTHOOK(10);
		tb2 = *(EIF_BOOLEAN *)(RTCW(loc3)+ _CHROFF_2_2_);
		if (tb2) break;
		RTHOOK(11);
		tr1 = F2521_28186(RTCW(loc3));
		tb3 = F2640_29132(RTCW(loc1), tr1);
		if (tb3) {
			RTHOOK(12);
			tr1 = F2521_28186(RTCW(loc3));
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R17660[Dtype(Result)-1604])(RTCW(Result), tr1);
			RTHOOK(13);
			F2640_29151(RTCW(loc1));
			RTHOOK(14);
			tr1 = F2521_28186(RTCW(loc3));
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R17662[Dtype(loc1)-1604])(RTCW(loc1), tr1);
		}
		RTHOOK(15);
		F2521_28205(RTCW(loc3));
	}
	RTHOOK(16);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R17810[Dtype(Result)-2453])(RTCW(Result), loc1);
	RTHOOK(17);
	RTLE;
	RTEE;
	return Result;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.main_area_drop_actions */
EIF_REFERENCE F3291_39803 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTEAA("main_area_drop_actions", 3290, Current, 0, 0, 41017);
	RTGC;
	RTHOOK(1);
	Result = F2715_30004(Current);
	Result = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_8_);
	Result = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_3_);
	Result = F638_10950(RTCW(Result));
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.docker_mediator */
EIF_REFERENCE F3291_39805 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {SD_DOCKING_MANAGER_PROPERTY}.set_docker_mediator */
void F3291_39806 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_docker_mediator", 3290, Current, 0, 1, 41003);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.resizable_items_data */
EIF_REFERENCE F3291_39807 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLR(3,loc1);
	RTLR(4,loc2);
	RTLR(5,loc3);
	RTLR(6,tr2);
	RTLIU(7);
	
	RTEAA("resizable_items_data", 3290, Current, 3, 0, 41004);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {2639,0xFFF9,2,3765,3982,3812,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNS(typres0.id, 2639, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F2640_29121(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	loc1 = F2715_30004(Current);
	loc1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_2_);
	loc1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
	RTHOOK(3);
	F2640_29151(RTCW(loc1));
	for (;;) {
		RTHOOK(4);
		tb1 = F2486_28004(RTCW(loc1));
		if (tb1) break;
		RTHOOK(5);
		loc2 = F2640_29125(RTCW(loc1));
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_2_);
		RTHOOK(6);
		F2640_29151(RTCW(loc2));
		for (;;) {
			RTHOOK(7);
			tb2 = F2486_28004(RTCW(loc2));
			if (tb2) break;
			RTHOOK(8);
			tr1 = F2640_29125(RTCW(loc2));
			loc3 = tr1;
			loc3 = RTRV(eif_new_type(1220, 0x00),loc3);
			if (EIF_TEST(loc3)) {
				RTHOOK(9);
				{
					static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,3765,3989,3812,0xFFFF};
					EIF_TYPE typres0;
					static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
					
					typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
					tr1 = RTLNTS(typres0.id, 3, 0);
				}
				tr2 = *(EIF_REFERENCE *)(loc3 + _REFACS_7_);
				((EIF_TYPED_VALUE *)tr1+1)->it_r = tr2;
				RTAR(tr1,tr2);
				tr2 = *(EIF_REFERENCE *)(loc3 + _REFACS_10_);
				ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R28190[Dtype(tr2)-2854])(RTCW(tr2));
				((EIF_TYPED_VALUE *)tr1+2)->it_i4 = ti4_1;
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R17660[Dtype(Result)-1604])(RTCW(Result), tr1);
			}
			RTHOOK(10);
			F2640_29153(RTCW(loc2));
		}
		RTHOOK(11);
		F2640_29153(RTCW(loc1));
	}
	RTHOOK(12);
	RTLE;
	RTEE;
	return Result;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.set_is_opening_config */
void F3291_39808 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_is_opening_config", 3290, Current, 0, 1, 41005);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_4_0_) = (EIF_BOOLEAN) arg1;
	RTHOOK(2);
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.set_content_first */
void F3291_39811 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("set_content_first", 3290, Current, 0, 1, 41008);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2470_27998(RTCW(tr1), arg1);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2521_28203(RTCW(tr1));
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2521_28212(RTCW(tr1), arg1);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.internal_clicked_list */
EIF_REFERENCE F3291_39812 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {SD_DOCKING_MANAGER_PROPERTY}.destroy */
void F3291_39813 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("destroy", 3290, Current, 0, 0, 41010);
	RTGC;
	RTHOOK(1);
	F2679_29337(RTCV(F3291_39803(Current)));
	RTHOOK(2);
	F2715_30003(Current);
	RTHOOK(3);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_4_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.remove_from_clicked_list */
void F3291_39814 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove_from_clicked_list", 3290, Current, 0, 1, 41011);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2470_27998(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

void EIF_Minit2331 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C47/sd2331.c <==
/*
 * Code for class SD_DOCKING_MANAGER_PROPERTY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "sd2331.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SD_DOCKING_MANAGER_PROPERTY}.make */
void F3295_35985 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make", 3294, Current, 0, 1, 41419);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {2536,3784,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F2517_26000(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.last_focus_content */
EIF_REFERENCE F3295_35986 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {SD_DOCKING_MANAGER_PROPERTY}.set_last_focus_content */
void F3295_35987 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("set_last_focus_content", 3294, Current, 0, 1, 41421);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	if ((EIF_BOOLEAN)(arg1 != NULL)) {
		RTHOOK(3);
		F3295_35997(Current, arg1);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.contents_by_click_order */
EIF_REFERENCE F3295_35988 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,loc3);
	RTLR(5,Result);
	RTLIU(6);
	
	RTEAA("contents_by_click_order", 3294, Current, 3, 0, 41422);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc2 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
	RTHOOK(2);
	F2630_26838(RTCW(loc2));
	RTHOOK(3);
	{
		static EIF_TYPE_INDEX typarr0[] = {2629,3784,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNS(typres0.id, 2629, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	ti4_1 = F2630_26828(RTCW(loc2));
	F2630_26808(RTCW(tr1), ti4_1);
	loc1 = (EIF_REFERENCE) tr1;
	for (;;) {
		RTHOOK(4);
		tb1 = F2482_25917(RTCW(loc2));
		if (tb1) break;
		RTHOOK(5);
		tr1 = F2630_26812(RTCW(loc2));
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R16037[Dtype(loc1)-1557])(RTCW(loc1), tr1);
		RTHOOK(6);
		F2630_26840(RTCW(loc2));
	}
	RTHOOK(7);
	loc3 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	RTHOOK(8);
	{
		static EIF_TYPE_INDEX typarr0[] = {2629,3784,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNS(typres0.id, 2629, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F2630_26808(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(9);
	F2517_26018(RTCW(loc3));
	for (;;) {
		RTHOOK(10);
		tb2 = *(EIF_BOOLEAN *)(RTCW(loc3)+ _CHROFF_2_2_);
		if (tb2) break;
		RTHOOK(11);
		tr1 = F2517_26001(RTCW(loc3));
		tb3 = F2630_26819(RTCW(loc1), tr1);
		if (tb3) {
			RTHOOK(12);
			tr1 = F2517_26001(RTCW(loc3));
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R16037[Dtype(Result)-1557])(RTCW(Result), tr1);
			RTHOOK(13);
			F2630_26838(RTCW(loc1));
			RTHOOK(14);
			tr1 = F2517_26001(RTCW(loc3));
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R16039[Dtype(loc1)-1557])(RTCW(loc1), tr1);
		}
		RTHOOK(15);
		F2517_26020(RTCW(loc3));
	}
	RTHOOK(16);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R16102[Dtype(Result)-2449])(RTCW(Result), loc1);
	RTHOOK(17);
	RTLE;
	RTEE;
	return Result;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.main_area_drop_actions */
EIF_REFERENCE F3295_35989 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTEAA("main_area_drop_actions", 3294, Current, 0, 0, 41423);
	RTGC;
	RTHOOK(1);
	Result = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_8_);
	Result = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_3_);
	Result = F2869_30156(RTCW(Result));
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.docker_mediator */
EIF_REFERENCE F3295_35991 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {SD_DOCKING_MANAGER_PROPERTY}.set_docker_mediator */
void F3295_35992 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_docker_mediator", 3294, Current, 0, 1, 41409);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.resizable_items_data */
EIF_REFERENCE F3295_35993 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLR(3,loc1);
	RTLR(4,loc2);
	RTLR(5,loc3);
	RTLR(6,tr2);
	RTLIU(7);
	
	RTEAA("resizable_items_data", 3294, Current, 3, 0, 41410);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {2629,0xFFF9,2,3840,4047,3857,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNS(typres0.id, 2629, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F2630_26808(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	loc1 = *(EIF_REFERENCE *)(Current);
	loc1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_2_);
	loc1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
	RTHOOK(3);
	F2630_26838(RTCW(loc1));
	for (;;) {
		RTHOOK(4);
		tb1 = F2482_25917(RTCW(loc1));
		if (tb1) break;
		RTHOOK(5);
		loc2 = F2630_26812(RTCW(loc1));
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_2_);
		RTHOOK(6);
		F2630_26838(RTCW(loc2));
		for (;;) {
			RTHOOK(7);
			tb2 = F2482_25917(RTCW(loc2));
			if (tb2) break;
			RTHOOK(8);
			tr1 = F2630_26812(RTCW(loc2));
			loc3 = tr1;
			loc3 = RTRV(eif_new_type(1198, 0x00),loc3);
			if (EIF_TEST(loc3)) {
				RTHOOK(9);
				{
					static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,3840,4050,3857,0xFFFF};
					EIF_TYPE typres0;
					static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
					
					typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
					tr1 = RTLNTS(typres0.id, 3, 0);
				}
				tr2 = *(EIF_REFERENCE *)(loc3 + _REFACS_7_);
				((EIF_TYPED_VALUE *)tr1+1)->it_r = tr2;
				RTAR(tr1,tr2);
				tr2 = *(EIF_REFERENCE *)(loc3 + _REFACS_10_);
				ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R25334[Dtype(tr2)-2787])(RTCW(tr2));
				((EIF_TYPED_VALUE *)tr1+2)->it_i4 = ti4_1;
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R16037[Dtype(Result)-1557])(RTCW(Result), tr1);
			}
			RTHOOK(10);
			F2630_26840(RTCW(loc2));
		}
		RTHOOK(11);
		F2630_26840(RTCW(loc1));
	}
	RTHOOK(12);
	RTLE;
	RTEE;
	return Result;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.set_is_opening_config */
void F3295_35994 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_is_opening_config", 3294, Current, 0, 1, 41411);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_4_0_) = (EIF_BOOLEAN) arg1;
	RTHOOK(2);
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.set_content_first */
void F3295_35997 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("set_content_first", 3294, Current, 0, 1, 41414);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2466_25911(RTCW(tr1), arg1);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2517_26018(RTCW(tr1));
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2517_26027(RTCW(tr1), arg1);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.internal_clicked_list */
EIF_REFERENCE F3295_35998 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {SD_DOCKING_MANAGER_PROPERTY}.destroy */
void F3295_35999 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("destroy", 3294, Current, 0, 0, 41416);
	RTGC;
	RTHOOK(1);
	F2669_26972(RTCV(F3295_35989(Current)));
	RTHOOK(2);
	{
		/* INLINED CODE (clear_docking_manager) */
		/* END INLINED CODE */
	}
	;
	RTHOOK(3);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_4_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {SD_DOCKING_MANAGER_PROPERTY}.remove_from_clicked_list */
void F3295_36000 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove_from_clicked_list", 3294, Current, 0, 1, 41417);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2466_25911(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

void EIF_Minit2331 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
